@@ -1,7 +1,7 @@
-from xhpy.constants import *
-from  xhpy.utils import htmlspecialchars, tag2class
+from ..constants import *
+from ..utils import htmlspecialchars, tag2class
 
-from exception import *
+from .exception import *
 
 ENABLE_VALIDATION = True
 
@@ -199,9 +199,12 @@ class :x:base(object):
   def __init__(self):
     raise NotImplementedError('not implemented!')
 
-  def __str__(self):
+  def __unicode__(self):
     raise NotImplementedError('not implemented!')
 
+  def __str__(self):
+    return unicode(self).encode('utf-8')
+
   def appendChild(self, child):
     raise NotImplementedError('not implemented!')
 
@@ -217,10 +220,10 @@ class :x:base(object):
   @classmethod
   def renderChild(cls, child):
     if isinstance(child, :x:base):
-      return str(child)
+      return unicode(child)
     if isinstance(child, list):
       raise XHPyRenderListException('Can not render list!')
-    return htmlspecialchars(str(child))
+    return htmlspecialchars(unicode(child))
 
 class :x:composable-element(:x:base):
   def _init(self):
@@ -261,6 +264,16 @@ class :x:composable-element(:x:base):
     tag_name = tag2class(tag_name)
     return [child for child in self._children if child.__class__.__name__ == tag_name]
 
+  def getNumChildren(self, tag_name=None):
+    return len(self.getChildren(tag_name))
+
+  def getFirstChild(self):
+    """
+    Fetches the first child of this element. If there are no children, an
+    exception will be thrown.
+    """
+    return self._children[0]
+
   def getAttribute(self, attr):
     """
     Fetches an attribute from this elements attribute store. If attr is not
@@ -321,7 +334,7 @@ class :x:primitive(:x:composable-element):
   def stringify(self):
     pass
 
-  def __str__(self):
+  def __unicode__(self):
     self._flushElementChildren()
     if ENABLE_VALIDATION:
       self._validator.validateChildren(self)
@@ -336,7 +349,7 @@ class :x:element(:x:composable-element):
   of markup.
   """
 
-  def __str__(self):
+  def __unicode__(self):
     that = self
     if ENABLE_VALIDATION:
       self._validator.validateChildren(that)
@@ -350,7 +363,7 @@ class :x:element(:x:composable-element):
       that = that.render()
       while isinstance(that, :x:element):
         that = that.render()
-    return str(that)
+    return unicode(that)
 
 class :x:frag(:x:primitive):
   """
